@@ -54,11 +54,12 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
             logger.error(f'write to kafka channel "{self._config.topic}" failed, error: {exc}')
             return False
 
-    async def mark_notification_as_read_internal(self, source_type: str, target_ids: list[int]) -> None:
+    async def mark_notification_as_read_internal(self, user_id: int, source_type: str, target_ids: list[int]) -> None:
         logger.debug(f'mark notification as read for source: {source_type}, targe: {target_ids}')
         async with self._http_client.post(
             f'{self._config.url}/v1/mark_notification_as_read_internal',
             json={
+                'user_id': user_id,
                 'source_type': source_type,
                 'target_ids': target_ids,
             },
